@@ -5,7 +5,8 @@
 ;; Author: Nasser Alshammari
 ;; URL: <https://github.com/nashamri/spacemacs-theme>
 ;;
-;; Version: 0.2
+;; Package-Version: 20251015.1823
+;; Package-Revision: f4757d701aa6
 ;; Keywords: color, theme
 ;; Package-Requires: ((emacs "24"))
 
@@ -342,22 +343,6 @@ to `auto', tags may not be properly aligned. "
      `(dired-symlink ((,class (:foreground ,cyan :background ,bg1 :inherit bold))))
      `(dired-warning ((,class (:foreground ,war))))
 
-;;;;; diredfl
-     `(diredfl-file-name ((,class (:foreground ,base))))
-     `(diredfl-file-suffix ((,class (:foreground ,magenta))))
-     `(diredfl-dir-name ((,class (:foreground ,keyword :inherit bold))))
-     `(diredfl-symlink ((,class (:foreground ,cyan :background ,bg1 :inherit bold))))
-     `(diredfl-deletion-file-name ((,class (:foreground ,red))))
-     `(diredfl-ignored-file-name ((,class (:inherit shadow))))
-     `(diredfl-dir-heading ((,class (:foreground ,comp :inherit bold))))
-     `(diredfl-date-time ((,class (:foreground ,yellow))))
-     `(diredfl-number ((,class (:foreground ,keyword))))
-     `(diredfl-write-priv ((,class (:foreground ,magenta))))
-     `(diredfl-exec-priv ((,class (:foreground ,cyan))))
-     `(diredfl-read-priv ((,class (:foreground ,aqua))))
-     `(diredfl-no-priv ((,class (:foreground ,base))))
-     `(diredfl-dir-priv ((,class (:foreground ,type))))
-
 ;;;;; dired-subtree
      `(dired-subtree-depth-1-face ((,class (:background ,bg1))))
      `(dired-subtree-depth-2-face ((,class (:background ,bg1))))
